Mengqi Guo has uploaded this change for review. ( https://review.coreboot.org/c/coreboot/+/31429
Change subject: mb/google/kahlee/var/baseboard: Enable mode change wake source for S3/S0ix
......................................................................
mb/google/kahlee/var/baseboard: Enable mode change wake source for S3/S0ix
This change enables mode change as a wake source for S3 and S0ix.
Change-Id: I95b1eac800858ab17cdf69bdd3f2c5828516c184
Signed-off-by: Mengqi Guo <mqg(a)chromium.org>
---
M src/mainboard/google/kahlee/variants/baseboard/include/baseboard/ec.h
1 file changed, 6 insertions(+), 2 deletions(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/29/31429/1
--
To view, visit https://review.coreboot.org/c/coreboot/+/31429
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings
Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: I95b1eac800858ab17cdf69bdd3f2c5828516c184
Gerrit-Change-Number: 31429
Gerrit-PatchSet: 1
Gerrit-Owner: Mengqi Guo <mqg(a)chromium.org>
Gerrit-MessageType: newchange
Martin Roth has uploaded this change for review. ( https://review.coreboot.org/c/coreboot/+/31424
Change subject: src/mainboard/kahlee: Remove delan variant
......................................................................
src/mainboard/kahlee: Remove delan variant
Change-Id: I348c7106772eecd513baf9abe60ef19008d0ba4d
Signed-off-by: Martin Roth <martinroth(a)google.com>
---
M src/mainboard/google/kahlee/Kconfig
M src/mainboard/google/kahlee/Kconfig.name
D src/mainboard/google/kahlee/variants/delan/Makefile.inc
D src/mainboard/google/kahlee/variants/delan/devicetree.cb
D src/mainboard/google/kahlee/variants/delan/include/variant/acpi/gpe.asl
D src/mainboard/google/kahlee/variants/delan/include/variant/acpi/mainboard.asl
D src/mainboard/google/kahlee/variants/delan/include/variant/acpi/routing.asl
D src/mainboard/google/kahlee/variants/delan/include/variant/acpi/sleep.asl
D src/mainboard/google/kahlee/variants/delan/include/variant/acpi/thermal.asl
D src/mainboard/google/kahlee/variants/delan/include/variant/ec.h
D src/mainboard/google/kahlee/variants/delan/include/variant/gpio.h
D src/mainboard/google/kahlee/variants/delan/include/variant/thermal.h
12 files changed, 0 insertions(+), 355 deletions(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/24/31424/1
diff --git a/src/mainboard/google/kahlee/Kconfig b/src/mainboard/google/kahlee/Kconfig
index 13ad0b9..1c46625 100644
--- a/src/mainboard/google/kahlee/Kconfig
+++ b/src/mainboard/google/kahlee/Kconfig
@@ -62,7 +62,6 @@
string
default "aleena" if BOARD_GOOGLE_ALEENA
default "careena" if BOARD_GOOGLE_CAREENA
- default "delan" if BOARD_GOOGLE_DELAN
default "grunt" if BOARD_GOOGLE_GRUNT
default "liara" if BOARD_GOOGLE_LIARA
@@ -116,7 +115,6 @@
depends on CHROMEOS
default "ALEENA TEST 7281" if BOARD_GOOGLE_ALEENA
default "CAREENA TEST 8777" if BOARD_GOOGLE_CAREENA
- default "DELAN TEST 0359" if BOARD_GOOGLE_DELAN
default "GRUNT TEST 8296" if BOARD_GOOGLE_GRUNT
default "LIARA TEST 0464" if BOARD_GOOGLE_LIARA
diff --git a/src/mainboard/google/kahlee/Kconfig.name b/src/mainboard/google/kahlee/Kconfig.name
index 941390f..c9401be 100644
--- a/src/mainboard/google/kahlee/Kconfig.name
+++ b/src/mainboard/google/kahlee/Kconfig.name
@@ -6,9 +6,6 @@
config BOARD_GOOGLE_CAREENA
bool "-> Careena"
select BOARD_GOOGLE_BASEBOARD_KAHLEE
-config BOARD_GOOGLE_DELAN
- bool "-> Delan"
- select BOARD_GOOGLE_BASEBOARD_KAHLEE
config BOARD_GOOGLE_GRUNT
bool "-> Grunt"
select BOARD_GOOGLE_BASEBOARD_KAHLEE
diff --git a/src/mainboard/google/kahlee/variants/delan/Makefile.inc b/src/mainboard/google/kahlee/variants/delan/Makefile.inc
deleted file mode 100644
index 0579e18..0000000
--- a/src/mainboard/google/kahlee/variants/delan/Makefile.inc
+++ /dev/null
@@ -1,20 +0,0 @@
-#
-# This file is part of the coreboot project.
-#
-# Copyright (C) 2017 Google, Inc.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-
-subdirs-y += ../baseboard/spd
-
-romstage-y += ../baseboard/romstage.c
-
-ramstage-y += ../baseboard/mainboard.c
diff --git a/src/mainboard/google/kahlee/variants/delan/devicetree.cb b/src/mainboard/google/kahlee/variants/delan/devicetree.cb
deleted file mode 100644
index b9cfe1b..0000000
--- a/src/mainboard/google/kahlee/variants/delan/devicetree.cb
+++ /dev/null
@@ -1,188 +0,0 @@
-#
-# This file is part of the coreboot project.
-#
-# Copyright (C) 2015-2017 Advanced Micro Devices, Inc.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-chip soc/amd/stoneyridge
- register "spd_addr_lookup" = "
- {
- { {0xA0, 0x00} }, // socket 0 - Channel 0, slot 0
- }"
- register "dram_clear_on_reset" = "DRAM_CONTENTS_KEEP"
- register "uma_mode" = "UMAMODE_SPECIFIED_SIZE"
- register "uma_size" = "32 * MiB"
-
- # Enable I2C0 for audio, USB3 hub at 400kHz
- register "i2c[0]" = "{
- .speed = I2C_SPEED_FAST,
- .rise_time_ns = 85,
- .fall_time_ns = 3,
- }"
-
- # Enable I2C1 for H1 at 400kHz
- register "i2c[1]" = "{
- .early_init = 1,
- .speed = I2C_SPEED_FAST,
- .rise_time_ns = 3,
- .fall_time_ns = 2,
- }"
-
- # Enable I2C2 for trackpad, pen at 400kHz
- register "i2c[2]" = "{
- .speed = I2C_SPEED_FAST,
- .rise_time_ns = 3,
- .fall_time_ns = 2,
- }"
-
- # Enable I2C3 for touchscreen at 400kHz
- register "i2c[3]" = "{
- .speed = I2C_SPEED_FAST,
- .rise_time_ns = 16,
- .fall_time_ns = 8,
- }"
-
- device cpu_cluster 0 on
- device lapic 10 on end
- end
- device domain 0 on
- device pci 0.0 on end # Root Complex
- device pci 0.2 off end # IOMMU (Disabled for performance and battery)
- device pci 1.0 on end # Internal Graphics P2P bridge 0x98e4
- device pci 1.1 on end # Internal Multimedia
- device pci 2.0 on end # PCIe Host Bridge
- device pci 2.1 on end #
- device pci 2.2 on end #
- device pci 2.3 on end #
- device pci 2.4 on
- chip drivers/generic/bayhub
- register "power_saving" = "1"
- device pci 00.0 on end
- end
- end #
- device pci 2.5 on end #
- device pci 8.0 on end # PSP
- device pci 9.0 on end # PCIe Host Bridge
- device pci 9.2 on end # HDA
- device pci 10.0 on end # xHCI
- device pci 11.0 off end # SATA
- device pci 12.0 on end # EHCI
- device pci 14.0 on # SMbus
- end # SMbus
- device pci 14.3 on
- chip ec/google/chromeec
- device pnp 0c09.0 on end
- end
- end # LPC
- device pci 14.7 on end # SD
- device pci 18.0 on end
- device pci 18.1 on end
- device pci 18.2 on end
- device pci 18.3 on end
- device pci 18.4 on end
- device pci 18.5 on end
- end #domain
- device mmio 0xfedc2000 on
- chip drivers/generic/adau7002
- device generic 0.0 on end
- end
- chip drivers/i2c/da7219
- register "irq_gpio" = "ACPI_GPIO_IRQ_EDGE_LOW(GPIO_14)"
- register "btn_cfg" = "50"
- register "mic_det_thr" = "500"
- register "jack_ins_deb" = "20"
- register "jack_det_rate" = ""32ms_64ms""
- register "jack_rem_deb" = "1"
- register "a_d_btn_thr" = "0xa"
- register "d_b_btn_thr" = "0x16"
- register "b_c_btn_thr" = "0x21"
- register "c_mic_btn_thr" = "0x3e"
- register "btn_avg" = "4"
- register "adc_1bit_rpt" = "1"
- register "micbias_lvl" = "2600"
- register "mic_amp_in_sel" = ""diff""
- register "mclk_name" = ""oscout1""
- device i2c 1a on end
- end
- chip drivers/generic/max98357a
- register "sdmode_gpio" = "ACPI_GPIO_OUTPUT_ACTIVE_HIGH(GPIO_119)"
- register "sdmode_delay" = "5"
- device generic 0.1 on end
- end
- end
- device mmio 0xfedc3000 on
- chip drivers/i2c/tpm
- register "hid" = ""GOOG0005""
- register "desc" = ""Cr50 TPM""
- register "irq_gpio" = "ACPI_GPIO_IRQ_EDGE_LOW(GPIO_9)"
- device i2c 50 on end
- end
- end
- device mmio 0xfedc4000 on
- chip drivers/i2c/generic
- register "hid" = ""ELAN0000""
- register "desc" = ""ELAN Touchpad""
- register "irq_gpio" = "ACPI_GPIO_IRQ_LEVEL_LOW(GPIO_5)"
- register "wake" = "7"
- register "probed" = "1"
- device i2c 15 on end
- end
- chip drivers/i2c/hid
- register "generic.hid" = ""PNP0C50""
- register "generic.desc" = ""Synaptics Touchpad""
- register "generic.irq_gpio" = "ACPI_GPIO_IRQ_LEVEL_LOW(GPIO_5)"
- register "generic.wake" = "7"
- register "generic.probed" = "1"
- register "hid_desc_reg_offset" = "0x20"
- device i2c 2c on end
- end
- end
- device mmio 0xfedc5000 on
- chip drivers/i2c/generic
- register "hid" = ""RAYD0001""
- register "desc" = ""Raydium Touchscreen""
- register "probed" = "1"
- register "irq_gpio" = "ACPI_GPIO_IRQ_LEVEL_LOW(GPIO_11)"
- register "reset_gpio" = "ACPI_GPIO_OUTPUT_ACTIVE_HIGH(GPIO_85)"
- register "reset_delay_ms" = "20"
- register "enable_gpio" = "ACPI_GPIO_OUTPUT_ACTIVE_HIGH(GPIO_76)"
- register "enable_delay_ms" = "1"
- register "has_power_resource" = "1"
- device i2c 39 on end
- end
- chip drivers/i2c/generic
- register "hid" = ""ELAN0001""
- register "desc" = ""ELAN Touchscreen""
- register "probed" = "1"
- register "irq_gpio" = "ACPI_GPIO_IRQ_LEVEL_LOW(GPIO_11)"
- register "reset_gpio" = "ACPI_GPIO_OUTPUT_ACTIVE_HIGH(GPIO_85)"
- register "reset_delay_ms" = "20"
- register "enable_gpio" = "ACPI_GPIO_OUTPUT_ACTIVE_HIGH(GPIO_76)"
- register "enable_delay_ms" = "1"
- register "has_power_resource" = "1"
- device i2c 10 on end
- end
- chip drivers/i2c/hid
- register "generic.hid" = ""WDHT0002""
- register "generic.desc" = ""WDT Touchscreen""
- register "generic.irq_gpio" = "ACPI_GPIO_IRQ_LEVEL_LOW(GPIO_11)"
- register "generic.probed" = "1"
- register "generic.reset_gpio" = "ACPI_GPIO_OUTPUT_ACTIVE_HIGH(GPIO_85)"
- register "generic.reset_delay_ms" = "130"
- register "generic.enable_gpio" = "ACPI_GPIO_OUTPUT_ACTIVE_HIGH(GPIO_76)"
- register "generic.enable_delay_ms" = "2"
- register "generic.has_power_resource" = "1"
- register "generic.disable_gpio_export_in_crs" = "1"
- register "hid_desc_reg_offset" = "0x20"
- device i2c 2c on end
- end
- end
-end #chip soc/amd/stoneyridge
diff --git a/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/gpe.asl b/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/gpe.asl
deleted file mode 100644
index 05cd0b9..0000000
--- a/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/gpe.asl
+++ /dev/null
@@ -1,14 +0,0 @@
-/*
- * This file is part of the coreboot project.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- */
-
-#include <baseboard/acpi/gpe.asl>
diff --git a/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/mainboard.asl b/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/mainboard.asl
deleted file mode 100644
index d026e9a..0000000
--- a/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/mainboard.asl
+++ /dev/null
@@ -1,15 +0,0 @@
-/*
- * This file is part of the coreboot project.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- */
-
-#include <baseboard/acpi/mainboard.asl>
-#include <baseboard/acpi/audio.asl>
diff --git a/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/routing.asl b/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/routing.asl
deleted file mode 100644
index c1896c3..0000000
--- a/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/routing.asl
+++ /dev/null
@@ -1,14 +0,0 @@
-/*
- * This file is part of the coreboot project.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- */
-
-#include <baseboard/acpi/routing.asl>
diff --git a/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/sleep.asl b/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/sleep.asl
deleted file mode 100644
index a401b3a..0000000
--- a/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/sleep.asl
+++ /dev/null
@@ -1,14 +0,0 @@
-/*
- * This file is part of the coreboot project.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- */
-
-#include <baseboard/acpi/sleep.asl>
diff --git a/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/thermal.asl b/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/thermal.asl
deleted file mode 100644
index a7e511c..0000000
--- a/src/mainboard/google/kahlee/variants/delan/include/variant/acpi/thermal.asl
+++ /dev/null
@@ -1,14 +0,0 @@
-/*
- * This file is part of the coreboot project.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- */
-
-#include <baseboard/acpi/thermal.asl>
diff --git a/src/mainboard/google/kahlee/variants/delan/include/variant/ec.h b/src/mainboard/google/kahlee/variants/delan/include/variant/ec.h
deleted file mode 100644
index e90724e..0000000
--- a/src/mainboard/google/kahlee/variants/delan/include/variant/ec.h
+++ /dev/null
@@ -1,17 +0,0 @@
-/*
- * This file is part of the coreboot project.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- */
-
-#include <baseboard/ec.h>
-
-/* Enable EC backed Keyboard Backlight in ACPI */
-#define EC_ENABLE_KEYBOARD_BACKLIGHT
diff --git a/src/mainboard/google/kahlee/variants/delan/include/variant/gpio.h b/src/mainboard/google/kahlee/variants/delan/include/variant/gpio.h
deleted file mode 100644
index 5a6b540..0000000
--- a/src/mainboard/google/kahlee/variants/delan/include/variant/gpio.h
+++ /dev/null
@@ -1,16 +0,0 @@
-/*
- * This file is part of the coreboot project.
- *
- * Copyright (C) 2017 Google Inc.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- */
-
-#include <baseboard/gpio.h>
diff --git a/src/mainboard/google/kahlee/variants/delan/include/variant/thermal.h b/src/mainboard/google/kahlee/variants/delan/include/variant/thermal.h
deleted file mode 100644
index 1bb78ef..0000000
--- a/src/mainboard/google/kahlee/variants/delan/include/variant/thermal.h
+++ /dev/null
@@ -1,38 +0,0 @@
-/*
- * This file is part of the coreboot project.
- *
- * Copyright (C) 2014 Google Inc.
- * Copyright (C) 2017 Advanced Micro Devices, Inc.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- */
-
-#ifndef THERMAL_H
-#define THERMAL_H
-
-/*
- * Stoney Ridge Thermal Requirements 12 (6W)
- * TDP (W) 6
- * T die,max (°C) 95
- * T ctl,max 85
- * T die,lmt (default) 90
- * T ctl,lmt (default) 80
- */
-
-/* Control TDP Settings */
-#define CTL_TDP_SENSOR_ID 2 /* EC TIN2 */
-
-/* Temperature which OS will shutdown at */
-#define CRITICAL_TEMPERATURE 94
-
-/* Temperature which OS will throttle CPU */
-#define PASSIVE_TEMPERATURE 85
-
-#endif
diff --git a/src/mainboard/google/kahlee/variants/baseboard/include/baseboard/ec.h b/src/mainboard/google/kahlee/variants/baseboard/include/baseboard/ec.h
index 976b621..ae648b5 100644
--- a/src/mainboard/google/kahlee/variants/baseboard/include/baseboard/ec.h
+++ b/src/mainboard/google/kahlee/variants/baseboard/include/baseboard/ec.h
@@ -44,10 +44,14 @@
(EC_HOST_EVENT_MASK(EC_HOST_EVENT_LID_OPEN) |\
EC_HOST_EVENT_MASK(EC_HOST_EVENT_POWER_BUTTON))
/* EC can wake from S3 with lid or power button or key press */
#define MAINBOARD_EC_S3_WAKE_EVENTS \
(MAINBOARD_EC_S5_WAKE_EVENTS |\
- EC_HOST_EVENT_MASK(EC_HOST_EVENT_KEY_PRESSED))
+ EC_HOST_EVENT_MASK(EC_HOST_EVENT_KEY_PRESSED) |\
+ EC_HOST_EVENT_MASK(EC_HOST_EVENT_MODE_CHANGE))
/* Log EC wake events plus EC shutdown events */
#define MAINBOARD_EC_LOG_EVENTS \
@@ -44,10 +44,14 @@
(EC_HOST_EVENT_MASK(EC_HOST_EVENT_LID_OPEN) |\
EC_HOST_EVENT_MASK(EC_HOST_EVENT_POWER_BUTTON))
-/* EC can wake from S3 with lid or power button or key press */
+/*
+ * EC can wake from S3 with lid or power button or key press or
+ * mode change event
+ */
#define MAINBOARD_EC_S3_WAKE_EVENTS \
(MAINBOARD_EC_S5_WAKE_EVENTS |\
--
To view, visit https://review.coreboot.org/c/coreboot/+/31424
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings
Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: I348c7106772eecd513baf9abe60ef19008d0ba4d
Gerrit-Change-Number: 31424
Gerrit-PatchSet: 1
Gerrit-Owner: Martin Roth <martinroth(a)google.com>
Gerrit-MessageType: newchange
mikeb mikeb has posted comments on this change. ( https://review.coreboot.org/c/coreboot/+/23856 )
Change subject: tint: introduce the new tint build system with checksum verification
......................................................................
Patch Set 9:
I just tested and it is still working (because there haven't been any major changes at buildgcc script that this build system is using)
--
To view, visit https://review.coreboot.org/c/coreboot/+/23856
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings
Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: I1d24f222d1b92030b81bba3951e243a2a9f37290
Gerrit-Change-Number: 23856
Gerrit-PatchSet: 9
Gerrit-Owner: mikeb mikeb <mikebdp2(a)gmail.com>
Gerrit-Reviewer: Jonathan Neuschäfer <j.neuschaefer(a)gmx.net>
Gerrit-Reviewer: Martin Roth <martinroth(a)google.com>
Gerrit-Reviewer: Patrick Rudolph <siro(a)das-labor.org>
Gerrit-Reviewer: Paul Menzel <paulepanter(a)users.sourceforge.net>
Gerrit-Reviewer: Stefan Reinauer <stefan.reinauer(a)coreboot.org>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Reviewer: mikeb mikeb <mikebdp2(a)gmail.com>
Gerrit-Comment-Date: Mon, 18 Feb 2019 20:19:26 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: No
Gerrit-MessageType: comment
Patrick Georgi has posted comments on this change. ( https://review.coreboot.org/c/coreboot/+/31467 )
Change subject: walkcbfs: Only compile on x86_32
......................................................................
Patch Set 1: Code-Review+2
--
To view, visit https://review.coreboot.org/c/coreboot/+/31467
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings
Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: Ibd87dc2979f6d45a988119c06c5f9e61b3e86171
Gerrit-Change-Number: 31467
Gerrit-PatchSet: 1
Gerrit-Owner: Patrick Rudolph <siro(a)das-labor.org>
Gerrit-Reviewer: Arthur Heymans <arthur(a)aheymans.xyz>
Gerrit-Reviewer: Martin Roth <martinroth(a)google.com>
Gerrit-Reviewer: Patrick Georgi <pgeorgi(a)google.com>
Gerrit-Reviewer: Patrick Rudolph <siro(a)das-labor.org>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Comment-Date: Mon, 18 Feb 2019 19:27:39 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment
Patrick Rudolph has uploaded a new patch set (#12) to the change originally created by Patrick Rudolph. ( https://review.coreboot.org/c/coreboot/+/29667 )
Change subject: mb/emulation/qemu-q35: x86_64 support
......................................................................
mb/emulation/qemu-q35: x86_64 support
* Enable optional x86_64 romstage, postcar and ramstage
* Add documentation for x86 qemu mainboards
* Increase CAR stack as x86_64 uses more than 0x4000 bytes
* Always setup MTRRs even though qemu doesn't care about them
Working:
* Boots to Linux
* Drops to protected mode at end of ramstage
* Enumerates PCI devices
* Relocateable ramstage
* postcar stage
Signed-off-by: Patrick Rudolph <siro(a)das-labor.org>
Change-Id: If2f02a95b2f91ab51043d4e81054354f4a6eb5d5
---
M Documentation/arch/x86/index.md
A Documentation/mainboard/emulation/qemu-i440fx.md
A Documentation/mainboard/emulation/qemu-q35.md
M Documentation/mainboard/index.md
M src/arch/x86/Kconfig
M src/cpu/qemu-x86/Kconfig
M src/cpu/qemu-x86/Makefile.inc
M src/mainboard/emulation/qemu-i440fx/Kconfig
M src/mainboard/emulation/qemu-i440fx/romstage.c
M src/mainboard/emulation/qemu-q35/Kconfig
M src/mainboard/emulation/qemu-q35/romstage.c
11 files changed, 209 insertions(+), 20 deletions(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/67/29667/12
--
To view, visit https://review.coreboot.org/c/coreboot/+/29667
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings
Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: If2f02a95b2f91ab51043d4e81054354f4a6eb5d5
Gerrit-Change-Number: 29667
Gerrit-PatchSet: 12
Gerrit-Owner: Patrick Rudolph <patrick.rudolph(a)9elements.com>
Gerrit-Reviewer: Aaron Durbin <adurbin(a)chromium.org>
Gerrit-Reviewer: Julius Werner <jwerner(a)chromium.org>
Gerrit-Reviewer: Martin Roth <martinroth(a)google.com>
Gerrit-Reviewer: Patrick Georgi <pgeorgi(a)google.com>
Gerrit-Reviewer: Patrick Rudolph <patrick.rudolph(a)9elements.com>
Gerrit-Reviewer: Patrick Rudolph <siro(a)das-labor.org>
Gerrit-Reviewer: Stefan Reinauer <stefan.reinauer(a)coreboot.org>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Reviewer: ron minnich <rminnich(a)gmail.com>
Gerrit-CC: Nico Huber <nico.h(a)gmx.de>
Gerrit-CC: Paul Menzel <paulepanter(a)users.sourceforge.net>
Gerrit-MessageType: newpatchset
Hello build bot (Jenkins),
I'd like you to reexamine a change. Please visit
https://review.coreboot.org/c/coreboot/+/30117
to look at the new patch set (#6).
Change subject: arch/x86: Support x86_64 exceptions
......................................................................
arch/x86: Support x86_64 exceptions
Tested on qemu using division by zero.
Doesn't affect existing x86_32 code.
Signed-off-by: Patrick Rudolph <siro(a)das-labor.org>
Change-Id: Idd12c90a95cc2989eb9b2a718740a84222193f48
---
M Documentation/arch/x86/index.md
M src/arch/x86/exception.c
M src/arch/x86/idt.S
M src/arch/x86/include/arch/registers.h
4 files changed, 116 insertions(+), 27 deletions(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/17/30117/6
--
To view, visit https://review.coreboot.org/c/coreboot/+/30117
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings
Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: Idd12c90a95cc2989eb9b2a718740a84222193f48
Gerrit-Change-Number: 30117
Gerrit-PatchSet: 6
Gerrit-Owner: Patrick Rudolph <siro(a)das-labor.org>
Gerrit-Reviewer: Patrick Rudolph <siro(a)das-labor.org>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-MessageType: newpatchset